/*
 *
 *  makeDisplay(history,canvasName)
 *
 *  Display the history of the execution of a 1D automaton.
 *
 *  Warren Sack <wsack@ucsc.edu>
 *  May 2017
 *
 */

function makeDisplay(history,canvasName) {

  window.resizeTo(screen.width,screen.height);
  var width = history[0].length;
  var height = history.length;
  var margin = 50;
  var lineWidth = 1;
  var squareWidth = ( screen.width - ( 2 * margin ) ) / width;
  var canvas = document.getElementById(canvasName);
  canvas.width = screen.width;
  canvas.height = squareWidth * ( height + 2 );
  var context = canvas.getContext('2d');

  //
  // drawHistory(ruleSetNumber,withGrid,withLabel)
  //
  function drawHistory(ruleSetNumber,withGrid,withLabel) {
    var x = margin;
    var y = screen.availTop;
    if ( withLabel) { y = y + ( 6 * squareWidth ); }
    context.font = "bold 64px Arial";
    if ( withLabel ) { 
      context.fillText(""+ruleSetNumber, x, y); 
      y = y + ( 2 * lineWidth );
      context.lineWidth = lineWidth;
      context.strokeStyle = 'white';
    }
    for ( var row = 0; row < height; row++ ) {
      for ( var column = 0; column < width; column++ ) {
	if ( withGrid ) { context.strokeRect(x,y,squareWidth,squareWidth); }
	if ( history[row][column] === "1" ) {
	  context.fillStyle = 'black';
	}
	else { context.fillStyle = 'white'; }
	if ( withGrid ) {
	  context.fillRect((x + lineWidth),
			   (y + lineWidth),
			   (squareWidth - (2 * lineWidth)),
			   (squareWidth - (2 * lineWidth)));
	}
	else { context.fillRect(x,y,squareWidth,squareWidth); }
	x = x + squareWidth;
      }
      x = margin;
      y = y + squareWidth;
    }
  }

  return({drawHistory : drawHistory});
 
}
