/*
 *  makeDisplayRuleSet(canvasName)
 *  
 *  Given a rule set number between 0 and 255, display
 *  the rule set as a series of eight figures rendered
 *  as black and white squares.
 *
 *  Warren Sack <wsack@ucsc.edu>
 *  May 2017
 *
 */
function makeDisplayRuleSet(canvasName) {
  window.resizeTo(screen.width,screen.height);
  var width = 31;
  var height = 3;
  var margin = 50;
  var lineWidth = 1;
  var squareWidth = ( screen.width - ( 2 * margin ) ) / width;
  var canvas = document.getElementById(canvasName);
  canvas.width = screen.width;
  canvas.height = squareWidth * ( height + 1 );
  var context = canvas.getContext('2d');
  
  //
  // drawRuleSet(ruleSetNumber): side-effects the DOM
  //
  function drawRuleSet(ruleSetNumber) {
    var x = margin;
    var y = screen.availTop;
    // draw the background white
    context.fillStyle = 'white';
    context.fillRect(margin,screen.availTop,canvas.width,canvas.height);
    // draw the 24 squares representing 0-7 in binary
    context.lineWidth = lineWidth;
    context.strokeStyle = 'gray';
    for ( var n = 7; n >= 0; n-- ) {
      var bits = decimalToBinary(n);
      bits = leftPadWithZeroes(bits,3);
      bits = bits.split("");
      for ( var bi = 0; bi < 3; bi++ ) {
	context.strokeRect(x,y,squareWidth,squareWidth);
	if ( bits[bi] === "1" ) { context.fillStyle = 'black';}
	else { context.fillStyle = 'white'; }
	context.fillRect((x + lineWidth),
			 (y + lineWidth),
			 (squareWidth - (2 * lineWidth)),
			 (squareWidth - (2 * lineWidth)));
	x = x + squareWidth;
      }
      x = x + squareWidth;
    }
    x = margin + squareWidth;
    y = y + squareWidth + (4 * lineWidth);
    // draw the ruleSetNumber in binary in the second row
    bits = decimalToBinary(ruleSetNumber);
    bits = leftPadWithZeroes(bits,8);
    bits = bits.split("");
    for ( var i = 0; i < 8; i++ ) {
      context.strokeRect(x,y,squareWidth,squareWidth);
      if ( bits[i] === "1" ) { context.fillStyle = 'black'; }
      else { context.fillStyle = 'white'; }
      context.fillRect((x + lineWidth),
		       (y + lineWidth),
		       (squareWidth - (2 * lineWidth)),
		       (squareWidth - (2 * lineWidth)));
      x = x + ( 4 * squareWidth);
    }
  }

  //
  // leftPadWithZeroes(s,l): string
  //
  function leftPadWithZeroes(s,l) {
    if ( s.length >= l ) { return(s); }
    else { return(leftPadWithZeroes("0" + s,l)); }
  }

  //
  // decimalToBinary(n): binary number as string
  //
  function decimalToBinary(n) {
    var binaryString = '';
    if ( n === 0 ) { return('0'); }
    while ( n > 0 ) {
      binaryString = ( n % 2 ) + binaryString;
      n = n >> 1;
    }
    return(binaryString);
  }

  return({ drawRuleSet : drawRuleSet });

}
