/*
 *  makeDisplayRuleSet(canvasName)
 *  
 *  Given a rule set number in binary for a 2D automaton (a 512 digit
 *  binary number), display the rule set as a series of 512 figures rendered
 *  as black and white squares.
 *
 *  Warren Sack <wsack@ucsc.edu>
 *  May 2017
 *
 */

function makeDisplayRuleSet(canvasName) {
  window.resizeTo(screen.width,screen.height);
  var width = 79;
  var height = 131;
  var margin = 100;
  var lineWidth = 1;
  var squareWidth = ( screen.width - ( 2 * margin ) ) / width;
  var canvas = document.getElementById(canvasName);
  var landscape = false;  // change this to false if a vertical layout is desired
  var numberPerRow = 512;
  if ( landscape ) {
    canvas.width = ( squareWidth * height ) + ( ( 4 * lineWidth ) * 25 );
    canvas.height = Math.ceil( height / width ) * screen.width;
    numberPerRow = 35;
  }
  else {
    canvas.width = screen.width;
    canvas.height = ( squareWidth * height ) + ( ( 4 * lineWidth ) * 25 );
    numberPerRow = 20;
  }
  var context = canvas.getContext('2d');
  var currentLeftEdge = margin;
  var currentTopEdge = screen.availTop - ( 5 * squareWidth ) - ( 4 * lineWidth );

  //
  // drawRuleSet(ruleSetNumber): side-effects the DOM
  //
  function drawRuleSet(ruleSetNumber) {
    ruleSetNumber = ruleSetNumber.split("");
    var x = currentLeftEdge;
    var y = currentTopEdge;
    var bits = "";
    // draw the background white
    context.fillStyle = 'white';
    context.fillRect(margin,screen.availTop,canvas.width,canvas.height);
    context.lineWidth = lineWidth;
    context.strokeStyle = 'gray';
    for ( var n = 511; n >= 0; n-- ) {
      if ( ( ( 511 - n ) % numberPerRow ) === 0 ) { 
	currentLeftEdge = margin; 
	currentTopEdge = currentTopEdge + ( 5 * squareWidth ) + ( 4 * lineWidth );
      }
      else { currentLeftEdge = currentLeftEdge + ( 4 * squareWidth ); }
      x = currentLeftEdge;
      y = currentTopEdge;
      bits = decimalToBinary(n);
      bits = leftPadWithZeroes(bits,9);
      bits = bits.split("");
      for ( var bi = 0; bi < 9; bi++ ) {
	context.strokeRect(x,y,squareWidth,squareWidth);
	if ( bits[bi] === "1" ) { context.fillStyle = 'black';}
	else { context.fillStyle = 'white'; }
	context.fillRect((x + lineWidth),
			 (y + lineWidth),
			 (squareWidth - (2 * lineWidth)),
			 (squareWidth - (2 * lineWidth)));
	if ( ( ( bi + 1 ) % 3 ) === 0 ) { 
	  x = currentLeftEdge; 
	  y = y + squareWidth;
	}
	else { x = x + squareWidth; }
      }
      // draw the current bit of the ruleSetNumber in the fourth row
      x = currentLeftEdge + squareWidth;
      y = currentTopEdge + ( 3 * squareWidth ) + ( 4 * lineWidth );
      context.strokeRect(x,y,squareWidth,squareWidth);
      if ( ruleSetNumber[511 - n] === "1" ) { context.fillStyle = 'black'; }
      else { context.fillStyle = 'white'; }
      context.fillRect((x + lineWidth),
		       (y + lineWidth),
		       (squareWidth - (2 * lineWidth)),
		       (squareWidth - (2 * lineWidth)));
    }
  }

  //
  // leftPadWithZeroes(s,l): string
  //
  function leftPadWithZeroes(s,l) {
    if ( s.length >= l ) { return(s); }
    else { return(leftPadWithZeroes("0" + s,l)); }
  }

  //
  // decimalToBinary(n): binary number as string
  //
  function decimalToBinary(n) {
    var binaryString = '';
    if ( n === 0 ) { return('0'); }
    while ( n > 0 ) {
      binaryString = ( n % 2 ) + binaryString;
      n = n >> 1;
    }
    return(binaryString);
  }

  return({ drawRuleSet : drawRuleSet });

}
